@@ -58,7 +58,7 @@ def createFields( runTime, mesh ):
     
     ext_Info() << "Creating turbulence model\n" << nl
     from Foam import compressible
-    turbulence = compressible.RASModel.New( rho,
+    turbulence = compressible.turbulenceModel.New( rho,
                                                     U,
                                                     phi,
                                                     thermo() )
@@ -75,7 +75,7 @@ def createFields( runTime, mesh ):
 #--------------------------------------------------------------------------------------
 def _UEqn( U, rho, phi, turbulence, p ):
     from Foam import fvm    
-    UEqn = fvm.ddt( rho, U ) + fvm.div( phi, U ) + turbulence.divDevRhoReff( U )
+    UEqn = fvm.ddt( rho, U ) + fvm.div( phi, U ) + turbulence.divRhoR( U )
     
     from Foam import fvc
     from Foam.finiteVolume import solve
@@ -101,10 +101,8 @@ def _pEqn( rho, thermo, UEqn, nNonOrthCorr, psi, U, mesh, phi, p, cumulativeCont
     from Foam import fvc
     from Foam.finiteVolume import surfaceScalarField
     from Foam.OpenFOAM import word
-    phid = surfaceScalarField( word( "phid" ), 
-                               fvc.interpolate( thermo.psi() ) * ( (fvc.interpolate( U ) & mesh.Sf() ) + fvc.ddtPhiCorr( rUA, rho, U, phi ) ) )
-    
-    
+    phid = surfaceScalarField( word( "phid" ), ( ( fvc.interpolate( rho * U ) & mesh.Sf() ) + fvc.ddtPhiCorr( rUA, rho, U, phi ) ) / fvc.interpolate( p ) )
+            
     for nonOrth in range( nNonOrthCorr + 1 ) :
         from Foam import fvm
         pEqn = ( fvm.ddt(psi, p) + fvm.div(phid, p) - fvm.laplacian(rho*rUA, p) )
@@ -150,7 +148,7 @@ def main_standalone( argc, argv ):
         ext_Info() << "Time = " << runTime.timeName() << nl << nl
         
         from Foam.finiteVolume.cfdTools.general.include import readPISOControls
-        piso, nCorr, nNonOrthCorr, momentumPredictor, transonic, nOuterCorr, ddtPhiCorr = readPISOControls( mesh )
+        piso, nCorr, nNonOrthCorr, momentumPredictor, transSonic, nOuterCorr = readPISOControls( mesh )
 
         from Foam.finiteVolume.cfdTools.compressible import compressibleCourantNo
         CoNum, meanCoNum = compressibleCourantNo( mesh, phi, rho, runTime )
@@ -193,17 +191,17 @@ def main_standalone( argc, argv ):
 
     
 #--------------------------------------------------------------------------------------
-from Foam import FOAM_REF_VERSION
-if FOAM_REF_VERSION( "==", "010500" ):
+from Foam import FOAM_VERSION
+if FOAM_VERSION( "<=", "010401" ):
    if __name__ == "__main__" :
       import sys, os
       argv = sys.argv
       os._exit( main_standalone( len( argv ), argv ) )
       pass
-   pass
+   pass   
 else :
    from Foam.OpenFOAM import ext_Info
-   ext_Info() << "\n\n To use this solver it is necessary to SWIG OpenFOAM-1.5\n"
+   ext_Info() << "\n\n To use this solver it is necessary to SWIG OpenFOAM-1.4.X\n"
    pass
 
 
